/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.provider.controller;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yifu.cloud.plus.v1.yifu.common.core.util.R;
import com.yifu.cloud.plus.v1.yifu.common.log.annotation.SysLog;
import com.yifu.cloud.plus.v1.provider.entity.Provider;
import com.yifu.cloud.plus.v1.provider.service.ProviderService;
import com.yifu.cloud.plus.v1.yifu.common.security.annotation.Inner;
import com.yifu.cloud.plus.v1.yifu.common.security.util.SecurityUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.security.SecurityRequirement;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpHeaders;
import org.springframework.web.bind.annotation.*;


/**
 * provider表
 *
 * @author fxj
 * @date 2022-05-13 23:28:32
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/provider" )
@Tag(name = "provider表管理")
@SecurityRequirement(name = HttpHeaders.AUTHORIZATION)
public class ProviderController {

    private final  ProviderService providerService;

    /**
     * 分页查询
     * @param page 分页对象
     * @param provider provider表
     * @return
     */
    @Operation(summary = "分页查询", description = "分页查询")
    @GetMapping("/page" )
    @PreAuthorize("@pms.hasPermission('provider_provider_get')" )
    public R getProviderPage(Page page, Provider provider) {
        return R.ok(providerService.page(page, Wrappers.query(provider)));
    }


    /**
     * 通过id查询provider表
     * @param id id
     * @return R
     */
    @Operation(summary = "通过id查询", description = "通过id查询")
    @GetMapping("/{id}" )
    @PreAuthorize("@pms.hasPermission('provider_provider_get')" )
    public R getById(@PathVariable("id" ) Long id) {
        return R.ok(providerService.getById(id));
    }

    /**
     * 新增provider表
     * @param provider provider表
     * @return R
     */
    @Operation(summary = "新增provider表", description = "新增provider表")
    @SysLog("新增provider表" )
    @PostMapping
    @PreAuthorize("@pms.hasPermission('provider_provider_add')" )
    public R save(@RequestBody Provider provider) {
		SecurityUtils.getAuthentication();
        return R.ok(providerService.save(provider));
    }
	/**
	 * 新增provider表
	 * @param provider provider表
	 * @return R
	 */
	@Operation(summary = "新增provider表", description = "新增provider表")
	@SysLog("新增provider表" )
	@Inner
	@PostMapping("/inner/save")
	public R saveInner(@RequestBody Provider provider) {
		return R.ok(providerService.save(provider));
	}
    /**
     * 修改provider表
     * @param provider provider表
     * @return R
     */
    @Operation(summary = "修改provider表", description = "修改provider表")
    @SysLog("修改provider表" )
    @PutMapping
    @PreAuthorize("@pms.hasPermission('provider_provider_edit')" )
    public R updateById(@RequestBody Provider provider) {
        return R.ok(providerService.updateById(provider));
    }

    /**
     * 通过id删除provider表
     * @param id id
     * @return R
     */
    @Operation(summary = "通过id删除provider表", description = "通过id删除provider表")
    @SysLog("通过id删除provider表" )
    @DeleteMapping("/{id}" )
    @PreAuthorize("@pms.hasPermission('provider_provider_del')" )
    public R removeById(@PathVariable Long id) {
        return R.ok(providerService.removeById(id));
    }

}
